Plot individual participants coloured by VVIQ group
Source:R/ggplot_tools.R
plot_coloured_subjects.RdThis function adds a layer to a ggplot object that plots individual data points coloured by VVIQ group.
Usage
plot_coloured_subjects(
x,
y,
df = aphantasiaEmotions::all_data,
alpha = 0.4,
...
)